containertools.Container
========================

.. abjad-lineage:: abjad.tools.containertools.Container.Container.Container

.. autoclass:: abjad.tools.containertools.Container.Container.Container
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.descendants
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.leaves
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.lineage
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.music
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.override
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.parent
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.parentage
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.prolation
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.set
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.spanners
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.start_offset
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.storage_format
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.timespan
   :noindex:

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.containertools.Container.Container.Container.is_parallel
   :noindex:

Methods
-------

.. automethod:: abjad.tools.containertools.Container.Container.Container.append
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.extend
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.index
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.insert
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.pop
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.containertools.Container.Container.Container.__add__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__contains__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__delitem__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__eq__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__ge__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__getitem__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__gt__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__iadd__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__imul__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__le__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__len__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__lt__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__mul__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__ne__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__radd__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__repr__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__rmul__
   :noindex:

.. automethod:: abjad.tools.containertools.Container.Container.Container.__setitem__
   :noindex:
